@@ -33,7 +33,7 @@ public:
     KonqSidebarHistoryDlg(QWidget *parent) : QWidget(parent)
     {
         setupUi(this);
-        layout()->setMargin(0);
+        layout()->setContentsMargins(0, 0, 0, 0);
     }
 };
 
